@@ -62,7 +62,12 @@ pub async fn execute(args: Args) -> miette::Result<()> {
         // Remove specs from the manifest
         let mut removed_dependencies = vec![];
         for spec in specs {
-            let package_name = spec.name.as_ref().expect("package name should be present");
+            let package_name = spec
+                .name
+                .as_ref()
+                .expect("package name should be present")
+                .as_exact()
+                .expect("package name must be exact");
             project
                 .manifest
                 .remove_dependency(env_name, package_name)
@@ -73,9 +78,10 @@ pub async fn execute(args: Args) -> miette::Result<()> {
         let prefix = project.environment_prefix(env_name).await?;
 
         for spec in specs {
-            if let Some(name) = spec.clone().name {
+            if let Some(name_matcher) = spec.clone().name {
+                let name = name_matcher.as_exact().expect("package name must be exact");
                 // If the package is not existent, don't try to remove executables
-                if let Ok(record) = prefix.find_designated_package(&name).await {
+                if let Ok(record) = prefix.find_designated_package(name).await {
                     prefix
                         .find_executables(&[record])
                         .into_iter()
