@@ -35,11 +35,14 @@
 mod backend_source_build;
 pub mod build;
 mod build_backend_metadata;
+mod cache;
 mod cache_dirs;
 mod command_dispatcher;
 mod command_dispatcher_processor;
+mod dev_source_metadata;
 mod discover_backend_cache;
 mod executor;
+mod input_hash;
 mod install_pixi;
 mod instantiate_tool_env;
 mod limits;
@@ -57,15 +60,20 @@ pub use backend_source_build::{
     BackendSourceBuildPrefix, BackendSourceBuildSpec, BackendSourceBuildV1Method,
 };
 pub use build::BuildEnvironment;
-pub use build_backend_metadata::calculate_additional_glob_hash;
 pub use build_backend_metadata::{
     BuildBackendMetadata, BuildBackendMetadataError, BuildBackendMetadataSpec,
 };
+pub use cache::build_backend_metadata::{BuildBackendMetadataCache, CachedCondaMetadata};
+pub use cache::common::MetadataCache;
+pub use cache::source_metadata::{CachedSourceMetadata, SourceMetadataCache};
 pub use cache_dirs::CacheDirs;
 pub use command_dispatcher::{
     CommandDispatcher, CommandDispatcherBuilder, CommandDispatcherError,
     CommandDispatcherErrorResultExt, InstantiateBackendError, InstantiateBackendSpec,
 };
+pub use dev_source_metadata::{
+    DevSourceMetadata, DevSourceMetadataError, DevSourceMetadataSpec, PackageNotProvidedError,
+};
 pub use executor::Executor;
 pub use install_pixi::{
     InstallPixiEnvironmentError, InstallPixiEnvironmentResult, InstallPixiEnvironmentSpec,
