@@ -14,7 +14,7 @@ use thiserror::Error;
 
 use crate::{
     BuildBackendMetadataSpec, BuildEnvironment, CommandDispatcher, CommandDispatcherError,
-    SourceCheckoutError, SourceMetadataSpec,
+    PackageNotProvidedError, SourceCheckoutError, SourceMetadataSpec,
     executor::ExecutorFutures,
     source_metadata::{CycleEnvironment, SourceMetadata, SourceMetadataError},
 };
@@ -52,13 +52,9 @@ pub enum CollectSourceMetadataError {
         #[diagnostic_source]
         error: SourceMetadataError,
     },
-    #[error("the package '{}' is not provided by the project located at '{}'", .name.as_source(), &.pinned_source)]
-    PackageMetadataNotFound {
-        name: rattler_conda_types::PackageName,
-        pinned_source: Box<PinnedSourceSpec>,
-        #[help]
-        help: String,
-    },
+    #[error(transparent)]
+    #[diagnostic(transparent)]
+    PackageNotProvided(#[from] PackageNotProvidedError),
     #[error("failed to checkout source for package '{name}'")]
     SourceCheckoutError {
         name: String,
@@ -94,7 +90,7 @@ impl SourceMetadataCollector {
 
     pub async fn collect(
         self,
-        specs: Vec<(rattler_conda_types::PackageName, SourceSpec)>,
+        specs: impl IntoIterator<Item = (rattler_conda_types::PackageName, SourceSpec)>,
     ) -> Result<CollectedSourceMetadata, CommandDispatcherError<CollectSourceMetadataError>> {
         let mut source_futures = ExecutorFutures::new(self.command_queue.executor());
         let mut specs = specs
@@ -125,7 +121,7 @@ impl SourceMetadataCollector {
             let (source_metadata, mut chain) = source_metadata?;
 
             // Process transitive dependencies
-            for record in &source_metadata.records {
+            for record in &source_metadata.cached_metadata.records {
                 chain.push(record.package_record.name.clone());
                 let anchor = SourceAnchor::from(SourceSpec::from(record.manifest_source.clone()));
                 for depend in &record.package_record.depends {
@@ -232,52 +228,6 @@ impl SourceMetadataCollector {
             Ok(metadata) => metadata,
         };
 
-        // Make sure that a package with the name defined in spec is available from the
-        // backend.
-        if source_metadata.records.is_empty() {
-            return Err(CommandDispatcherError::Failed(
-                CollectSourceMetadataError::PackageMetadataNotFound {
-                    help: Self::create_metadata_not_found_help(
-                        &name,
-                        source_metadata.skipped_packages.clone(),
-                    ),
-                    name,
-                    pinned_source: Box::new(source_metadata.source.manifest_source().clone()),
-                },
-            ));
-        }
-
         Ok((source_metadata, chain))
     }
-
-    /// Create a help message for the user when the requested package is not
-    /// found in the metadata returned by a backend.
-    fn create_metadata_not_found_help(
-        name: &rattler_conda_types::PackageName,
-        skipped_packages: Vec<rattler_conda_types::PackageName>,
-    ) -> String {
-        skipped_packages
-            .into_iter()
-            .map(|skipped_name| {
-                (
-                    strsim::jaro(skipped_name.as_normalized(), name.as_normalized()),
-                    skipped_name,
-                )
-            })
-            .max_by(|(score_a, _), (score_b, _)| {
-                score_a
-                    .partial_cmp(score_b)
-                    .unwrap_or(std::cmp::Ordering::Equal)
-            })
-            .map(|(_, record)| record)
-            .map_or_else(
-                || String::from("No packages are provided by the build-backend"),
-                |skipped_name| {
-                    format!(
-                        "The build backend does provide other packages, did you mean '{}'?",
-                        skipped_name.as_normalized(),
-                    )
-                },
-            )
-    }
 }
