@@ -10,7 +10,7 @@ use futures::TryStreamExt;
 use itertools::{Either, Itertools};
 use miette::Diagnostic;
 use pixi_build_types::procedures::conda_outputs::CondaOutput;
-use pixi_record::{InputHash, PixiRecord, SourceRecord};
+use pixi_record::{PixiRecord, SourceRecord};
 use pixi_spec::{BinarySpec, PixiSpec, SourceAnchor, SourceSpec, SpecConversionError};
 use pixi_spec_containers::DependencyMap;
 use rattler_conda_types::{
@@ -21,13 +21,16 @@ use rattler_repodata_gateway::{RunExportExtractorError, RunExportsReporter};
 use thiserror::Error;
 use tracing::instrument;
 
+use crate::cache::build_backend_metadata::CachedCondaMetadataId;
+use crate::cache::source_metadata::CachedSourceMetadataId;
 use crate::{
     BuildBackendMetadataError, BuildBackendMetadataSpec, BuildEnvironment, CommandDispatcher,
-    CommandDispatcherError, CommandDispatcherErrorResultExt, PixiEnvironmentSpec,
-    SolvePixiEnvironmentError,
-    build::{
-        Dependencies, DependenciesError, PixiRunExports, SourceCodeLocation, conversion,
-        source_metadata_cache::MetadataKind,
+    CommandDispatcherError, CommandDispatcherErrorResultExt, PackageNotProvidedError,
+    PixiEnvironmentSpec, SolvePixiEnvironmentError,
+    build::{Dependencies, DependenciesError, PixiRunExports, SourceCodeLocation},
+    cache::{
+        common::MetadataCache,
+        source_metadata::{self, CachedSourceMetadata, SourceMetadataCacheShard},
     },
     executor::ExecutorFutures,
 };
@@ -42,16 +45,13 @@ pub struct SourceMetadataSpec {
 }
 
 /// The result of building a particular source record.
-#[derive(Debug, Clone)]
+#[derive(Debug)]
 pub struct SourceMetadata {
     /// Manifest and optional build source location for this metadata.
     pub source: SourceCodeLocation,
 
-    /// All the source records for this particular package.
-    pub records: Vec<SourceRecord>,
-
-    /// All package names that where skipped but the backend could provide.
-    pub skipped_packages: Vec<PackageName>,
+    /// The metadata that was acquired from the build backend.
+    pub cached_metadata: CachedSourceMetadata,
 }
 
 impl SourceMetadataSpec {
@@ -60,7 +60,7 @@ impl SourceMetadataSpec {
         name = "source-metadata",
         fields(
             manifest_source= %self.backend_metadata.manifest_source,
-            preferred_build_source=?self.backend_metadata.preferred_build_source,
+            preferred_build_source=self.backend_metadata.preferred_build_source.as_ref().map(tracing::field::display),
             name = %self.package.as_source(),
             platform = %self.backend_metadata.build_environment.host_platform,
         )
@@ -78,57 +78,138 @@ impl SourceMetadataSpec {
 
         let build_backend_metadata = build_backend_metadata?;
 
-        match &build_backend_metadata.metadata.metadata {
-            MetadataKind::GetMetadata { packages } => {
-                let source_location = build_backend_metadata.source.clone();
-                // Convert the metadata to source records.
-                let records = conversion::package_metadata_to_source_records(
-                    source_location.manifest_source(),
-                    source_location.build_source(),
-                    packages,
-                    &self.package,
-                    &build_backend_metadata.metadata.input_hash,
-                );
+        tracing::trace!(
+            "Retrieving source metadata for package {}",
+            self.package.as_source()
+        );
 
-                Ok(SourceMetadata {
-                    source: source_location,
-                    records,
-                    // As the GetMetadata kind returns all records at once and we don't solve them we can skip this.
-                    skipped_packages: Default::default(),
-                })
+        let cache_key = self.cache_key();
+
+        // Get the skip_cache flag from the build backend metadata
+        let skip_cache = build_backend_metadata.skip_cache;
+
+        let cache_read_result = command_dispatcher
+            .source_metadata_cache()
+            .read(&cache_key)
+            .await
+            .map_err(SourceMetadataError::Cache)
+            .map_err(CommandDispatcherError::Failed)?;
+
+        let (cached_metadata, cache_version) = match cache_read_result {
+            Some((metadata, version)) => (Some(metadata), version),
+            // Start at cache version 0 if no cache exists
+            None => (None, 0),
+        };
+
+        if !skip_cache
+            && let Some(cached_metadata) =
+                Self::verify_cache_freshness(cached_metadata, build_backend_metadata.metadata.id)
+                    .await?
+        {
+            tracing::debug!("Using cached source metadata for package",);
+            return Ok(SourceMetadata {
+                source: build_backend_metadata.source.clone(),
+                cached_metadata,
+            });
+        }
+
+        let mut futures = ExecutorFutures::new(command_dispatcher.executor());
+        let source_location = build_backend_metadata.source.clone();
+        for output in &build_backend_metadata.metadata.outputs {
+            if output.metadata.name != self.package {
+                continue;
             }
-            MetadataKind::Outputs { outputs } => {
-                let mut skipped_packages = vec![];
-                let mut futures = ExecutorFutures::new(command_dispatcher.executor());
-                let source_location = build_backend_metadata.source.clone();
-                for output in outputs {
-                    if output.metadata.name != self.package {
-                        skipped_packages.push(output.metadata.name.clone());
-                        continue;
-                    }
-                    futures.push(self.resolve_output(
-                        &command_dispatcher,
-                        output,
-                        build_backend_metadata.metadata.input_hash.clone(),
-                        source_location.clone(),
-                        reporter.clone(),
-                    ));
-                }
+            futures.push(self.resolve_output(
+                &command_dispatcher,
+                output,
+                source_location.clone(),
+                reporter.clone(),
+            ));
+        }
 
-                Ok(SourceMetadata {
-                    source: source_location,
-                    records: futures.try_collect().await?,
-                    skipped_packages,
-                })
+        let records: Vec<SourceRecord> = futures.try_collect().await?;
+
+        // Ensure the source provides the requested package
+        if records.is_empty() {
+            let available_names = build_backend_metadata
+                .metadata
+                .outputs
+                .iter()
+                .map(|output| output.metadata.name.clone());
+            return Err(CommandDispatcherError::Failed(
+                PackageNotProvidedError::new(
+                    self.package,
+                    build_backend_metadata.source.manifest_source().clone(),
+                    available_names,
+                )
+                .into(),
+            ));
+        }
+
+        let cached_source_metadata = CachedSourceMetadata {
+            id: CachedSourceMetadataId::random(),
+            cache_version,
+            records,
+            cached_conda_metadata_id: build_backend_metadata.metadata.id,
+        };
+
+        // Try to store the metadata in the cache with version checking
+        match command_dispatcher
+            .source_metadata_cache()
+            .try_write(&cache_key, cached_source_metadata.clone(), cache_version)
+            .await
+            .map_err(SourceMetadataError::Cache)
+            .map_err(CommandDispatcherError::Failed)?
+        {
+            source_metadata::WriteResult::Written => {
+                tracing::trace!("Cache updated successfully");
+            }
+            source_metadata::WriteResult::Conflict(_) => {
+                tracing::warn!(
+                    "Cache was updated by another process during computation (version conflict), using our computed result"
+                );
             }
         }
+
+        Ok(SourceMetadata {
+            cached_metadata: cached_source_metadata,
+            source: source_location,
+        })
+    }
+
+    /// Computes the cache key for this instance
+    pub(crate) fn cache_key(&self) -> SourceMetadataCacheShard {
+        SourceMetadataCacheShard {
+            package: self.package.clone(),
+            channel_urls: self.backend_metadata.channels.clone(),
+            build_environment: self.backend_metadata.build_environment.clone(),
+            enabled_protocols: self.backend_metadata.enabled_protocols.clone(),
+            pinned_source: self.backend_metadata.manifest_source.clone(),
+        }
+    }
+
+    async fn verify_cache_freshness(
+        cached_metadata: Option<CachedSourceMetadata>,
+        current_conda_metadata_id: CachedCondaMetadataId,
+    ) -> Result<Option<CachedSourceMetadata>, CommandDispatcherError<SourceMetadataError>> {
+        let Some(cached_metadata) = cached_metadata else {
+            tracing::debug!("no cached metadata passed.");
+            return Ok(None);
+        };
+
+        if cached_metadata.cached_conda_metadata_id != current_conda_metadata_id {
+            // Not adding tracing here because the backend metadata would already have done that.
+            tracing::info!("Cached metadata is stale, skipping cache");
+            return Ok(None);
+        }
+
+        Ok(Some(cached_metadata))
     }
 
     async fn resolve_output(
         &self,
         command_dispatcher: &CommandDispatcher,
         output: &CondaOutput,
-        input_hash: Option<InputHash>,
         source: SourceCodeLocation,
         reporter: Option<Arc<dyn RunExportsReporter>>,
     ) -> Result<SourceRecord, CommandDispatcherError<SourceMetadataError>> {
@@ -167,7 +248,7 @@ impl SourceMetadataSpec {
                 reporter.clone(),
             )
             .await
-            .map_err(SourceMetadataError::from)
+            .map_err(|err| SourceMetadataError::RunExportsExtraction(String::from("build"), err))
             .map_err(CommandDispatcherError::Failed)?;
 
         // Solve the host environment for the output.
@@ -198,7 +279,7 @@ impl SourceMetadataSpec {
                 reporter,
             )
             .await
-            .map_err(SourceMetadataError::from)
+            .map_err(|err| SourceMetadataError::RunExportsExtraction(String::from("host"), err))
             .map_err(CommandDispatcherError::Failed)?;
 
         // Gather the dependencies for the output.
@@ -350,7 +431,6 @@ impl SourceMetadataSpec {
                 experimental_extra_depends: Default::default(),
             },
             manifest_source,
-            input_hash,
             build_source,
             sources: sources
                 .into_iter()
@@ -397,6 +477,7 @@ impl SourceMetadataSpec {
                     .into_specs()
                     .map(|(name, spec)| (name, spec.value))
                     .collect(),
+                dev_sources: Default::default(),
                 installed: vec![], // TODO: To lock build environments, fill this.
                 build_environment,
                 channels: self.backend_metadata.channels.clone(),
@@ -493,8 +574,8 @@ pub enum SourceMetadataError {
     #[diagnostic(transparent)]
     BuildBackendMetadata(#[from] BuildBackendMetadataError),
 
-    #[error("failed to amend run exports: {0}")]
-    RunExportsExtraction(#[from] RunExportExtractorError),
+    #[error("failed to amend run exports for {0} environment")]
+    RunExportsExtraction(String, #[source] RunExportExtractorError),
 
     #[error("while trying to solve the build environment for the package")]
     SolveBuildEnvironment(
@@ -526,6 +607,13 @@ pub enum SourceMetadataError {
 
     #[error("the dependencies of some packages in the environment form a cycle")]
     Cycle(Cycle),
+
+    #[error(transparent)]
+    Cache(#[from] source_metadata::SourceMetadataCacheError),
+
+    #[error(transparent)]
+    #[diagnostic(transparent)]
+    PackageNotProvided(#[from] PackageNotProvidedError),
 }
 
 impl From<DependenciesError> for SourceMetadataError {
