@@ -10,6 +10,7 @@ use rattler_conda_types::{
 
 use crate::{
     CondaDependencies, PrioritizedChannel, PyPiDependencies, SpecType, SystemRequirements,
+    dependencies::CondaDevDependencies,
     has_features_iter::HasFeaturesIter,
     has_manifest_ref::HasWorkspaceManifest,
     pypi::pypi_options::PypiOptions,
@@ -207,6 +208,20 @@ pub trait FeaturesExt<'source>: HasWorkspaceManifest<'source> + HasFeaturesIter<
         DependencyMap::merge_all(deps.iter().map(|d| d.as_ref()))
     }
 
+    /// Returns the combined dev dependencies to install for this collection.
+    ///
+    /// Dev dependencies from all features in the group are collected and
+    /// merged. If multiple features define the same dev dependency, the
+    /// last one wins (later features override earlier ones).
+    fn combined_dev_dependencies(&self, platform: Option<Platform>) -> CondaDevDependencies {
+        let deps: Vec<_> = self
+            .features()
+            .filter_map(|f| f.dev_dependencies(platform))
+            .collect();
+
+        DependencyMap::merge_all(deps.iter().map(|d| d.as_ref()))
+    }
+
     /// Returns the pypi options for this collection.
     ///
     /// The pypi options of all features are combined. They will be combined in
