@@ -1,5 +1,5 @@
 use crate::utils::extract_directory_from_url;
-use crate::{Pep508ToPyPiRequirementError, PixiPypiSpec, VersionOrStar};
+use crate::{Pep508ToPyPiRequirementError, PixiPypiSource, PixiPypiSpec, VersionOrStar};
 use pixi_git::GitUrl;
 use pixi_spec::GitSpec;
 use std::path::Path;
@@ -10,11 +10,13 @@ impl TryFrom<pep508_rs::Requirement> for PixiPypiSpec {
     fn try_from(req: pep508_rs::Requirement) -> Result<Self, Self::Error> {
         let converted = if let Some(version_or_url) = req.version_or_url {
             match version_or_url {
-                pep508_rs::VersionOrUrl::VersionSpecifier(v) => PixiPypiSpec::Version {
-                    version: v.into(),
-                    extras: req.extras,
-                    index: None,
-                },
+                pep508_rs::VersionOrUrl::VersionSpecifier(v) => PixiPypiSpec::with_extras(
+                    PixiPypiSource::Registry {
+                        version: v.into(),
+                        index: None,
+                    },
+                    req.extras,
+                ),
                 pep508_rs::VersionOrUrl::Url(u) => {
                     let url = u.to_url();
                     if let Some((prefix, ..)) = url.scheme().split_once('+') {
@@ -28,10 +30,10 @@ impl TryFrom<pep508_rs::Requirement> for PixiPypiSpec {
                                     subdirectory,
                                 };
 
-                                Self::Git {
-                                    url: git_spec,
-                                    extras: req.extras,
-                                }
+                                PixiPypiSpec::with_extras(
+                                    PixiPypiSource::Git { git: git_spec },
+                                    req.extras,
+                                )
                             }
                             "bzr" => {
                                 return Err(Pep508ToPyPiRequirementError::UnsupportedUrlPrefix {
@@ -73,38 +75,41 @@ impl TryFrom<pep508_rs::Requirement> for PixiPypiSpec {
                             rev: Some(git_url.reference().clone().into()),
                             subdirectory,
                         };
-                        Self::Git {
-                            url: git_spec,
-                            extras: req.extras,
-                        }
+                        PixiPypiSpec::with_extras(PixiPypiSource::Git { git: git_spec }, req.extras)
                     } else if url.scheme().eq_ignore_ascii_case("file") {
                         // Convert the file url to a path.
                         let file = url.to_file_path().map_err(|_| {
                             Pep508ToPyPiRequirementError::PathUrlIntoPath(url.clone())
                         })?;
-                        PixiPypiSpec::Path {
-                            path: file,
-                            editable: None,
-                            extras: req.extras,
-                        }
+                        PixiPypiSpec::with_extras(
+                            PixiPypiSource::Path {
+                                path: file,
+                                editable: None,
+                            },
+                            req.extras,
+                        )
                     } else {
                         let subdirectory = extract_directory_from_url(&url);
-                        PixiPypiSpec::Url {
-                            url,
-                            extras: req.extras,
-                            subdirectory,
-                        }
+                        PixiPypiSpec::with_extras(
+                            PixiPypiSource::Url { url, subdirectory },
+                            req.extras,
+                        )
                     }
                 }
             }
         } else if !req.extras.is_empty() {
-            PixiPypiSpec::Version {
-                version: VersionOrStar::Star,
-                extras: req.extras,
-                index: None,
-            }
+            PixiPypiSpec::with_extras(
+                PixiPypiSource::Registry {
+                    version: VersionOrStar::Star,
+                    index: None,
+                },
+                req.extras,
+            )
         } else {
-            PixiPypiSpec::RawVersion(VersionOrStar::Star)
+            PixiPypiSpec::new(PixiPypiSource::Registry {
+                version: VersionOrStar::Star,
+                index: None,
+            })
         };
         Ok(converted)
     }
